# chromakey

A chroma key (green screen removal) package in Python, vectorised with numpy.

Algorithm from http://gc-films.com/chromakey.html.

## TODO

- Add OBS chroma key algorithm
    - https://github.com/obsproject/obs-studio/blob/master/plugins/obs-filters/data/chroma_key_filter.effect
